### FEIOS
* An os still indev.
* Developed by fyc,it is remade.

### Changelog
#### Changelog @ 0.3.0a1
* Fixed Unfixed IndexError in the main module.
#### Changelog @ 0.3.0dev3
* Uploaded README.md
#### Changelog @ 0.3.0dev2
* Fixed IndexError(requires feios_utils >= 0.2.0b3)(README.md not uploaded)
#### Changelog @ 0.3.0dev1
* Added support back to py3.5.
* Fixed some IndexError.